.. Benzina documentation master file, created by
   sphinx-quickstart on Mon Nov 12 17:09:52 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: links.rst


=================
Бензина / Benzina
=================


Table of Contents
=================

.. toctree::
   :maxdepth: 2

   examples/_index.rst
   datasets/list.rst
   objectives.rst
   limits.rst
   roadmap.rst
   contribution/_index.rst
   api/_index.rst


.. include:: description.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
